PCB Environment: RecordRangesROP Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
RecordRangesROP Class Referencefinal
Inheritance diagram for RecordRangesROP:

## Public Member Functions
void | reserve (uint N)
void | writeRangeZYX (uint Z0, uint Z1, uint Y0, uint Y1, uint X0, uint X1) override
const std::vector< IndexRange > & | getRanges () const
Public Member Functions inherited from BaseROP
void | reserve (uint N)
void | writeRangeZX (uint Z0, uint Z1, uint Y, uint X0, uint X1)
void | writeRangeZY (uint Z0, uint Z1, uint Y0, uint Y1, uint X)
void | writeRangeYX (uint Z, uint Y0, uint Y1, uint X0, uint X1)
void | writeRangeY (uint Z, uint Y0, uint Y1, uint X)
void | writeRangeX (uint Z, uint Y, uint X0, uint X1)

## Member Function Documentation

## ◆ writeRangeZYX()

void RecordRangesROP::writeRangeZYX | ( | uint | Z0,
|  | uint | Z1,
|  | uint | Y0,
|  | uint | Y1,
|  | uint | X0,
|  | uint | X1 )
| inlineoverridevirtual

Implements BaseROP.

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Rasterizer.hpp